@@ -18,28 +18,11 @@
 #define HTTP_SERVER_HPP
 
 #ifdef HTTP_WITH_SSL
-
-#ifdef BOOST_ASIO
 #include <boost/asio.hpp>
 #include <boost/asio/ssl.hpp>
 namespace asio = boost::asio;
-#else // !BOOST_ASIO
-#include <asio.hpp>
-#include <asio/ssl.hpp>
-#endif // BOOST_ASIO
-
 #endif // HTTP_WITH_SSL
 
-#if defined(THREADED) && BOOST_VERSION < 103600
-
-#ifdef BOOST_ASIO
-#include <boost/asio/detail/select_reactor.hpp>
-#else // !BOOST_ASIO
-#include <asio/detail/select_reactor.hpp>
-#endif // BOOST_ASIO
-
-#endif // defined(THREADED) && BOOST_VERSION < 103600
-
 #include <string>
 #include <boost/noncopyable.hpp>
 #include <boost/version.hpp>
@@ -50,6 +33,7 @@ namespace asio = boost::asio;
 #include "SslConnection.h"
 #endif // HTTP_WITH_SSL
 
+#include "Configuration.h"
 #include "ConnectionManager.h"
 #include "RequestHandler.h"
 
@@ -67,43 +51,49 @@ class Server
 public:
   /// Construct the server to listen on the specified TCP address and port, and
   /// serve up files from the given directory.
-  explicit Server(const Configuration& config,
-		  const Wt::Configuration& wtConfig);
+  explicit Server(const Configuration& config, Wt::WServer& wtServer);
 
   ~Server();
 
-  /// Run the server's io_service loop.
-  void run();
+  /// Start the server (called from constructor)
+  void start();
 
   /// Stop the server.
   void stop();
 
-  /// Select for read on descriptor
-  void select_read(int descriptor);
+  /// Assumes accept sockets have been closed and reopens them.
+  void resume();
 
-  /// Select for read on descriptor
-  void select_write(int descriptor);
+  /// Returns the http port number.
+  int httpPort() const;
 
-  /// Select for exceptions on descriptor
-  void select_except(int descriptor);
+  Wt::WebController *controller();
 
-  /// Stop selecting on the descriptor
-  void stop_select(int descriptor);
+  const Configuration &configuration() { return config_; }
 
-  static Server* instance() { return instance_; }
+  asio::io_service &service();
 
 private:
+  /// Starts accepting http/https connections
+  void startAccept();
+
   /// Handle completion of an asynchronous accept operation.
   void handleTcpAccept(const asio_error_code& e);
 
   /// Handle a request to stop the server.
   void handleStop();
 
-  /// The logger
-  Wt::WLogger   accessLogger_;
+  /// Handle a request to resume the server.
+  void handleResume();
 
-  /// The io_service used to perform asynchronous operations.
-  asio::io_service io_service_;
+  /// The server's configuration
+  Configuration config_;
+
+  /// The Wt app server
+  Wt::WServer& wt_;
+
+  /// The logger
+  Wt::WLogger accessLogger_;
 
   /// The strand for handleTcpAccept(), handleSslAccept() and handleStop()
   asio::strand accept_strand_;
@@ -125,10 +115,9 @@ private:
   SslConnectionPtr new_sslconnection_;
 #endif // HTTP_WITH_SSL
 
-#if defined(THREADED) && BOOST_VERSION < 103600
-  /// Reactor that listens for selects() on auxiliary sockets. 
-  asio::detail::select_reactor<false> select_reactor_;
-#endif // defined(THREADED) && BOOST_VERSION < 103600
+void handleTimeout(asio::deadline_timer *timer,
+		   const boost::function<void ()>& function,
+		   const asio_error_code& err);
 
   /// The connection manager which owns all live connections.
   ConnectionManager connection_manager_;
@@ -138,12 +127,6 @@ private:
 
   /// The handler for all incoming requests.
   RequestHandler request_handler_;
-
-  bool socketSelected(int descriptor, const asio_error_code& e,
-		      std::size_t bytes_transferred,
-		      asio::ip::tcp::socket *s);
-
-  static Server *instance_;
 };
 
 } // namespace server
