@@ -20,12 +20,8 @@
 #include <string>
 #include <vector>
 #include <fstream>
-#ifdef BOOST_ASIO
 #include <boost/asio.hpp>
 namespace asio = boost::asio;
-#else
-#include <asio.hpp>
-#endif
 
 #include "Reply.h"
 
@@ -38,27 +34,38 @@ class Request;
 class StaticReply : public Reply
 {
 public:
-  StaticReply(const std::string &full_path, const std::string &extension,
-	      const Request& request, const std::string &err_root);
+  StaticReply(const Request& request, const Configuration& config);
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest);
+  virtual void reset(const Wt::EntryPoint *ep);
+  virtual void writeDone(bool success);
+
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state);
 
 protected:
-  virtual status_type responseStatus();
   virtual std::string contentType();
-  virtual boost::intmax_t contentLength();
+  virtual ::int64_t contentLength();
 
-  virtual asio::const_buffer nextContentBuffer();
+  virtual bool nextContentBuffers(std::vector<asio::const_buffer>& result);
 
 private:
-  std::string     path_;
-  std::string     extension_;
-  std::ifstream   stream_;
-  boost::intmax_t fileSize_;
+  std::string path_;
+  std::string extension_;
+  std::ifstream stream_;
+  ::int64_t fileSize_;
 
   char buf_[64 * 1024];
+
+  std::string computeModifiedDate() const;
+  std::string computeETag() const;
+  static std::string computeExpires();
+
+  void parseRangeHeader();
+  bool hasRange_;
+  ::int64_t rangeBegin_;
+  ::int64_t rangeEnd_;
+
 };
 
 } // namespace server
