@@ -19,12 +19,8 @@
 
 #include <string>
 #include <vector>
-#ifdef BOOST_ASIO
 #include <boost/asio.hpp>
 namespace asio = boost::asio;
-#else
-#include <asio.hpp>
-#endif
 
 #include "Reply.h"
 #include "WHttpDllDefs.h"
@@ -36,26 +32,26 @@ namespace server {
 class WTHTTP_API StockReply : public Reply
 {
 public:
-  StockReply(const Request& request, status_type status);
   StockReply(const Request& request, status_type status,
-	     std::string extraContent);
-  StockReply(const Request& request, status_type status,
-	     const std::string &extraContent, const std::string &err_root);
+	     const Configuration& configuration);
 
-  virtual void consumeRequestBody(Buffer::const_iterator begin,
-				  Buffer::const_iterator end,
-				  bool endOfRequest);
+  StockReply(const Request& request, status_type status,
+	     std::string extraContent,
+	     const Configuration& configuration);
+
+  virtual void reset(const Wt::EntryPoint *ep);
+
+  virtual void consumeData(Buffer::const_iterator begin,
+			   Buffer::const_iterator end,
+			   Request::State state);
 
 protected:
-  virtual status_type responseStatus();
   virtual std::string contentType();
-  virtual boost::intmax_t contentLength();
+  virtual ::int64_t contentLength();
 
-  virtual asio::const_buffer nextContentBuffer();  
+  virtual bool nextContentBuffers(std::vector<asio::const_buffer>& result);
 
 private:
-  status_type status_;
-  std::string err_root_;
   std::string content_;
   bool transmitted_;
 };
